@@ -5,12 +5,11 @@ nfmatch<-function(z,p,fine,X,dat,caliper,constant=NULL,ncontrol=1,rank=T,exact=N
   stopifnot(is.vector(z))
   stopifnot(is.vector(p))
   if (is.factor(fine)){
-    levels(fine)=1:nlevels(fine)
+    levels(fine)<-1:nlevels(fine)
     fine<-as.integer(fine)
   }
   stopifnot(is.vector(fine))
   fine<-as.numeric(fine)
-  stopifnot(length(unique(fine))>=2)
   stopifnot(all((z==1)|(z==0)))
   stopifnot((ncontrol==round(ncontrol))&(ncontrol>=1))
   stopifnot(length(z)==length(p))
@@ -23,8 +22,8 @@ nfmatch<-function(z,p,fine,X,dat,caliper,constant=NULL,ncontrol=1,rank=T,exact=N
   if (is.vector(X)) X<-matrix(X,length(X),1)
   if (is.data.frame(nearexact)) nearexact<-as.matrix(nearexact)
   if (is.factor(nearexact)){
-    levels(nearexact)=1:nlevels(nearexact)
-    nearexact=as.numeric(nearexact)
+    levels(nearexact)<-1:nlevels(nearexact)
+    nearexact<-as.numeric(nearexact)
   }
   if (is.vector(nearexact)) nearexact<-matrix(nearexact,length(nearexact),1)
   if (is.data.frame(Xextra)) Xextra<-as.matrix(Xextra)
@@ -37,7 +36,7 @@ nfmatch<-function(z,p,fine,X,dat,caliper,constant=NULL,ncontrol=1,rank=T,exact=N
   if (sub) stopifnot(!is.null(subX))
   if (!is.null(subX)){
     if (is.factor(subX)){
-      levels(subX)=1:nlevels(subX)
+      levels(subX)<-1:nlevels(subX)
       subX<-as.integer(subX)
     }
     stopifnot(is.vector(subX))
@@ -45,7 +44,7 @@ nfmatch<-function(z,p,fine,X,dat,caliper,constant=NULL,ncontrol=1,rank=T,exact=N
 
   if (!is.null(exact)){
     if (is.factor(exact)){
-      levels(exact)=1:nlevels(exact)
+      levels(exact)<-1:nlevels(exact)
       exact<-as.integer(exact)
     }
   }
@@ -58,25 +57,25 @@ nfmatch<-function(z,p,fine,X,dat,caliper,constant=NULL,ncontrol=1,rank=T,exact=N
     exact<-exact[o]
   }
 
-  or <- rank(1-p,ties.method = 'min')
+  or<-rank(1-p,ties.method='min')
   z<-z[o]
   p<-p[o]
-  or <- or[o]
+  or<-or[o]
   fine<-fine[o]
   X<-X[o,]
   dat<-dat[o,]
-  if (!is.null(nearexact)) nearexact=nearexact[o,]
-  if (!is.null(Xextra)) Xextra=Xextra[o,]
-  if (!is.null(subX)) subX=subX[o]
+  if (!is.null(nearexact)) nearexact<-nearexact[o,]
+  if (!is.null(Xextra)) Xextra<-Xextra[o,]
+  if (!is.null(subX)) subX<-subX[o]
 
   #do match
-  timeind=proc.time()
+  timeind<-proc.time()
   if (rank){
     dist<-smahal(z,or,X,caliper,constant,exact,nearexact,Xextra,weight)
   }else{
     dist<-smahal(z,p,X,caliper,constant,exact,nearexact,Xextra,weight)
   }
-  timeind=proc.time()-timeind
+  timeind<-proc.time()-timeind
   m<-nearfine(z,fine,dist,dat,X,ncontrol,penalty,max.cost,nearexPenalty,sub,subX)
   if(m[[1]]==0) {
     if (!is.null(exact)) warning("The match you requested is infeasible.  Reconsider caliper, ncontrol and exact.")
